@@ -36,17 +36,16 @@
  */
 
 int
-Jpegtcl_Init (interp)
-      Tcl_Interp *interp; /* Interpreter to initialise. */
+Jpegtcl_Init (Tcl_Interp *interp) /* Interpreter to initialise. */
 {
   extern const JpegtclStubs jpegtclStubs;
 
-  if (Tcl_InitStubs(interp, "8.3", 0) == NULL) {
+  if (Tcl_InitStubs(interp, "8.6-", 0) == NULL) {
     return TCL_ERROR;
   }
   /* DO NOT USE PACKAGE_VERSION, USE INFO FROM jpegtcl.h INSTEAD */
   if (Tcl_PkgProvideEx(interp, PACKAGE_NAME, JPEGTCL_VERSION,
-		       (ClientData) &jpegtclStubs) != TCL_OK) {
+                       (ClientData) &jpegtclStubs) != TCL_OK) {
     return TCL_ERROR;
   }
 
@@ -71,8 +70,7 @@ Jpegtcl_Init (interp)
  */
 
 int
-Jpegtcl_SafeInit (interp)
-      Tcl_Interp *interp; /* Interpreter to initialise. */
+Jpegtcl_SafeInit (Tcl_Interp *interp) /* Interpreter to initialise. */
 {
     return Jpegtcl_Init(interp);
 }
