@@ -41,7 +41,7 @@ Pngtcl_Init (Tcl_Interp *interp) /* Interpreter to initialise. */
 {
   extern const PngtclStubs pngtclStubs;
 
-  if (Tcl_InitStubs(interp, "8.3", 0) == NULL) {
+  if (Tcl_InitStubs(interp, "8.6-", 0) == NULL) {
     return TCL_ERROR;
   }
   if (Zlibtcl_InitStubs(interp, ZLIBTCL_VERSION, 1) == NULL) {
@@ -49,7 +49,7 @@ Pngtcl_Init (Tcl_Interp *interp) /* Interpreter to initialise. */
   }
 
   if (Tcl_PkgProvideEx(interp, PACKAGE_NAME, PACKAGE_VERSION,
-		       (ClientData) &pngtclStubs) != TCL_OK) {
+                       (ClientData) &pngtclStubs) != TCL_OK) {
     return TCL_ERROR;
   }
 
